==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/docking_notify/translations/docking_notify_es_MX.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_MX">
<context>
    <name>@default</name>
    <message>
        <source>Notification</source>
        <translation>Notificación</translation>
    </message>
    <message>
        <source>Tray Icon Balloon</source>
        <translation>Globo de icono de bandeja</translation>
    </message>
    <message>
        <source>Timeout</source>
        <translation>Tiempo de espera</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation>
            <numerusform>%n segundo(s)</numerusform>
            <numerusform>%n segundo(s)</numerusform>
        </translation>
    </message>
    <message>
        <source>Notification icon</source>
        <translation>Icono de notificación</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Crítica</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Syntax</source>
        <translation>Sintaxis</translation>
    </message>
    <message>
        <source>No Icon</source>
        <translation>Sin Icono</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notificaciones</translation>
    </message>
</context>
<context>
    <name>Qt4NotifyConfigurationWidget</name>
    <message>
        <source>Configure</source>
        <translation>Configurar</translation>
    </message>
    <message>
        <source>Tray icon balloon&apos;s look configuration</source>
        <translation>Configuración de apariencia del globo de icono de bandeja</translation>
    </message>
    <message>
        <source>
%&amp;t - title (eg. New message) %&amp;m - notification text (eg. Message from Jim), %&amp;d - details (eg. message quotation),
%&amp;i - notification icon</source>
        <translation>
%&amp;t - título (ejemplo. Nuevo mensaje) %&amp;m - texto de la notificación (ejemplo. Mensaje de Jim), %&amp;d - detalles (ejemplo. cita del mensaje),
%&amp;i - icono de la notificación</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/docking_notify/translations/docking_notify_es_MX.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_MX">
<context>
    <name>@default</name>
    <message>
        <source>Notification</source>
        <translation>Notificación</translation>
    </message>
    <message>
        <source>Tray Icon Balloon</source>
        <translation>Globo de icono de bandeja</translation>
    </message>
    <message>
        <source>Timeout</source>
        <translation>Tiempo de espera</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation>
            <numerusform>%n segundo(s)</numerusform>
            <numerusform>%n segundo(s)</numerusform>
        </translation>
    </message>
    <message>
        <source>Notification icon</source>
        <translation>Icono de notificación</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Información</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Crítica</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Título</translation>
    </message>
    <message>
        <source>Syntax</source>
        <translation>Sintaxis</translation>
    </message>
    <message>
        <source>No Icon</source>
        <translation>Sin Icono</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Notificaciones</translation>
    </message>
</context>
<context>
    <name>DockingNotifyConfigurationWidget</name>
    <message>
        <source>Configure</source>
        <translation type="unfinished">Configurar</translation>
    </message>
    <message>
        <source>Tray icon balloon&apos;s look configuration</source>
        <translation type="unfinished">Configuración de apariencia del globo de icono de bandeja</translation>
    </message>
    <message>
        <source>
%&amp;t - title (eg. New message) %&amp;m - notification text (eg. Message from Jim), %&amp;d - details (eg. message quotation),
%&amp;i - notification icon</source>
        <translation type="unfinished">
%&amp;t - título (ejemplo. Nuevo mensaje) %&amp;m - texto de la notificación (ejemplo. Mensaje de Jim), %&amp;d - detalles (ejemplo. cita del mensaje),
%&amp;i - icono de la notificación</translation>
    </message>
</context>
</TS>
